==> wildfly-clustering-ejb-spi-7.0.4.GA-redhat-2-sources.jar: org/wildfly/clustering/ejb/BeanManagerFactoryBuilderFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

import java.util.Collection;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.ee.Batch;
import org.wildfly.clustering.service.Builder;

public interface BeanManagerFactoryBuilderFactory<I, B extends Batch> {

    /**
     * Installs dependencies for a deployment unit
     * @param name the service name of the deployment unit
     */
    Collection<Builder<?>> getDeploymentBuilders(ServiceName name);

    /**
     * Builds a bean manager factory for an EJB within a deployment.
     * @param context the bean context
     * @return a service builder
     */
    <T> Builder<? extends BeanManagerFactory<I, T, B>> getBeanManagerFactoryBuilder(BeanContext context);
}

==> wildfly-clustering-ejb-spi-7.1.3.GA-redhat-2-sources.jar: org/wildfly/clustering/ejb/BeanManagerFactoryBuilderFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

import java.util.Collection;

import org.jboss.as.clustering.controller.CapabilityServiceBuilder;
import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.ee.Batch;
import org.wildfly.clustering.service.Builder;

public interface BeanManagerFactoryBuilderFactory<I, B extends Batch> {

    /**
     * Installs dependencies for a deployment unit
     * @param name the service name of the deployment unit
     */
    Collection<CapabilityServiceBuilder<?>> getDeploymentBuilders(ServiceName name);

    /**
     * Builds a bean manager factory for an EJB within a deployment.
     * @param context the bean context
     * @return a service builder
     */
    <T> Builder<? extends BeanManagerFactory<I, T, B>> getBeanManagerFactoryBuilder(BeanContext context);
}
